@@ -16,17 +16,15 @@ from argo_client.connection import DynamicSocketProcess, ServerConnection, Serve
 from . import cryptoltypes
 from . import solver
 from .bitvector import BV
+from .cryptoltypes import fail_with
+from .quoting import cry, cry_f
 from .commands import *
 from .connection import *
+# import everything from `.synchronous` except `connect` and `connect_stdio`
+#  (since functions with those names were already imported from `.connection`)
+from .synchronous import Qed, Safe, Counterexample, Satisfiable, Unsatisfiable, CryptolSyncConnection
+# and add an alias `sync` for the `synchronous` module
+from . import synchronous
+sync = synchronous
 
-
-__all__ = ['bitvector', 'commands', 'connections', 'cryptoltypes', 'solver']
-
-
-def fail_with(x : Exception) -> NoReturn:
-    "Raise an exception. This is valid in expression positions."
-    raise x
-
-
-def cry(string : str) -> cryptoltypes.CryptolCode:
-    return cryptoltypes.CryptolLiteral(string)
+__all__ = ['bitvector', 'commands', 'connection', 'cryptoltypes', 'opaque', 'quoting', 'single_connection', 'solver', 'synchronous']
